@@ -1,16 +1,8 @@
 gen_year_list <- function(data_year) {
-    if (data_year == 2013) {
-        years <- seq(2000, 2012, 1)
-    } else if (data_year == 2014) {
-        years <- seq(2000, 2013, 1)
-    } else if (data_year == 2015) {
-        years <- seq(2000, 2014, 1)
-    } else if (data_year == 2016) {
-        years <- seq(2000, 2015, 1)
-    } else if (data_year == 2017) {
-        years <- seq(2000, 2016, 1)
-    } else if (data_year > 2017) {
-        years <- seq(2000, data_year - 1, 1)
+    if (data_year >= 2013 | data_year <= 2018){
+        years <- seq(2000, data_year, 1)
+    } else if (data_year > 2018) {
+        years <- seq(2000, data_year, 1)
         warning('data_year ', data_year, ' is not offically supported. Check that statistics output matches expected (in particular the years in the output table).')
     } else {
         stop('data_year ', data_year, ' is not supported')
@@ -30,7 +22,7 @@ gen_year_list <- function(data_year) {
 #' \code{\link{extract_gfc}} to extract the GFC data for the AOI, and threshold 
 #' it using \code{\link{threshold_gfc}} prior to running this function.
 #'
-#' If the\code{aoi} \code{SpatialPolygons*} object is not in the coordinate 
+#' If the\code{aoi} object is not in the coordinate 
 #' system of \code{gfc}, it will be reprojected. If there is a "label" 
 #' attribute, it will be used to label the output statistics.  Otherwise, 
 #' unique names ("AOI 1", "AOI 2", etc.) will be generated and used to label 
@@ -46,7 +38,7 @@ gen_year_list <- function(data_year) {
 #' @importFrom rgeos gIntersects
 #' @importFrom sp spTransform CRS proj4string
 #' @param aoi one or more Area of Interest (AOI) polygon(s) as a 
-#' \code{SpatialPolygons*} object. See Details.
+#' \code{SpatialPolygons*}. See Details.
 #' @param gfc extract of GFC product for a given AOI (see 
 #' \code{\link{extract_gfc}}), recoded using \code{\link{threshold_gfc}}.
 #' @param scale_factor how to scale the output data (from meters). Defaults to 
@@ -56,11 +48,12 @@ gen_year_list <- function(data_year) {
 #' statistics on forest loss, and "gain_table", with the area of forest gain, 
 #' and area that experienced both loss and gain. The units of the output are 
 #' hectares (when \code{scale_factor} is set to .0001).
-gfc_stats <- function(aoi, gfc, scale_factor=.0001, dataset='GFC-2017-v1.5') {
+gfc_stats <- function(aoi, gfc, scale_factor=.0001, dataset='GFC-2019-v1.7') {
     names(gfc) <- c('forest2000', 'lossyear', 'gain', 'lossgain', 'datamask')
     gfc_boundpoly <- as(extent(gfc), 'SpatialPolygons')
     proj4string(gfc_boundpoly) <- proj4string(gfc)
     gfc_boundpoly_wgs84 <- spTransform(gfc_boundpoly, CRS('+init=epsg:4326'))
+    aoi <- check_aoi(aoi)
     aoi_wgs84 <- spTransform(aoi, CRS('+init=epsg:4326'))
     if (!gIntersects(gfc_boundpoly_wgs84, aoi_wgs84)) {
         stop('aoi does not intersect supplied GFC extract')
